# Bioacoustic Augmentations


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install bioacoustics in Development mode

``` sh
# make sure bioacoustics package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to bioacoustics
$ nbdev_prepare
```

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/itepifanio/bioacoustics):

``` sh
$ pip install git+https://github.com/itepifanio/bioacoustics.git
```

or from [conda](https://anaconda.org/itepifanio/bioacoustics)

``` sh
$ conda install -c itepifanio bioacoustics
```

or from [pypi](https://pypi.org/project/bioacoustics/)

``` sh
$ pip install bioacoustics
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/itepifanio/bioacoustics)’s
[pages](https://itepifanio.github.io/bioacoustics/). Additionally you
can find package manager specific guidelines on
[conda](https://anaconda.org/itepifanio/bioacoustics) and
[pypi](https://pypi.org/project/bioacoustics/) respectively.
